apparmor: rename hname_tail to basename

Rename to the shorter and more familiar shell cmd name

Signed-off-by: John Johansen <john.johansen@canonical.com>
diff --git a/security/apparmor/include/lib.h b/security/apparmor/include/lib.h
index 4ff09ed..b5c16d3 100644
--- a/security/apparmor/include/lib.h
+++ b/security/apparmor/include/lib.h
@@ -130,12 +130,12 @@ struct aa_policy {
 };
 
 /**
  * hname_tail - find the last component of an hname
  * @name: hname to find the base profile name component of  (NOT NULL)
  *
  * Returns: the tail (base profile name) name component of an hname
  */
-static inline const char *hname_tail(const char *hname)
+static inline const char *basename(const char *hname)
 {
 	char *split;
@@ -130,12 +130,12 @@ struct aa_policy {
 
 /**
- * hname_tail - find the last component of an hname
+ * basename - find the last component of an hname
  * @name: hname to find the base profile name component of  (NOT NULL)
  *